@@ -1,10 +1,11 @@
 import os
+import shutil
 from pathlib import Path
 from typing import Optional
 
 from nox import Session
 
-from lndb._clone import setup_local_test_postgres
+from lndb.dev import setup_local_test_postgres
 
 from ._env import get_package_name
 
@@ -22,6 +23,11 @@ def login_testuser1(session: Session):
     session.run(*(login_user_1.split(" ")), external=True)
 
 
+def login_testuser2(session: Session):
+    login_user_1 = "lndb login testuser2@lamin.ai --password goeoNJKE61ygbz1vhaCVynGERaRrlviPBVQsjkhz"  # noqa
+    session.run(*(login_user_1.split(" ")), external=True)
+
+
 def setup_test_instances_from_main_branch(session: Session, schema: str = None):
     # spin up a postgres test instance
     pgurl = setup_local_test_postgres()
@@ -64,3 +70,27 @@ def build_docs(session: Session):
     prefix = "." if Path("./lndocs").exists() else ".."
     session.install(f"{prefix}/lndocs")
     session.run("lndocs")
+
+
+def upload_docs_dir():
+    import lndb
+
+    if os.environ["GITHUB_EVENT_NAME"] != "push":
+        return
+    package_name = get_package_name()
+    filestem = f"{package_name}_docs"
+    filename = shutil.make_archive(filestem, "zip", "./docs")
+    lndb.load("testuser1/lamin-site-assets", migrate=True)
+
+    import lamindb as ln
+    import lamindb.schema as lns
+
+    with ln.Session() as ss:
+        dobject = ss.select(ln.DObject, name=filestem).one_or_none()
+        pipeline = ln.add(lns.Pipeline, name=f"CI {package_name}")
+        run = lns.Run(pipeline=pipeline)
+        if dobject is None:
+            dobject = ln.DObject(filename, source=run)
+        else:
+            dobject.run = run
+        ss.add(dobject)
